.. module:: wwdtm

*************
API Reference
*************

The ``wwdtm`` library provides corresponding modules to retrieve data for
guests, hosts, locations, panelists, scorekeepers, and shows from a copy
of the Wait Wait Don't Tell Me! Stats database.

The following is a list of modules provided in the library:

.. toctree::
    :maxdepth: 2

    guest
    host
    location
    panelist
    pronoun
    scorekeeper
    show
    validation
